# tools-lyc7456

lyc7456 运维开发小工具。

## 0.0.8 更新内容

2021-10-4：uCloudapi EIP方法封装

## 0.0.7 更新内容

2021-7-8：优化公共方法：timestamp

## 0.0.6 更新内容

2021-7-7：增加公共方法：时间、目录扫描

## 0.0.5 更新内容

2021-7-7：发布正式环境

## 0.0.4 更新内容

2021-7-7：
* 优化百度云bos文件简单下载功能
* 调整包目录结构
* 增加包 log

## 0.0.3 更新内容

2021-7-6 百度云存储bos，短信sms服务封装

## 0.0.2 更新内容

2021-7-6 更新README.md

## 0.0.1 更新内容

2021-7-6 开发库创建，上传代码
